@@ -1,5 +1,6 @@
 import codecs
 from collections import defaultdict
+import copy
 import csv
 from functools import reduce
 import json
@@ -198,11 +199,16 @@ class ResultSet(list, ColumnGuesserMixin):
             graph = nx.MultiGraph()
         for item in self._results.graph:
             for node in item['nodes']:
-                graph.add_node(node['id'], node['properties'],
-                               labels=node['labels'])
+                properties = copy.deepcopy(node['properties'])
+                properties['labels'] = node['labels']
+                graph.add_node(node['id'], properties)
             for rel in item['relationships']:
-                graph.add_edge(rel['startNode'], rel['endNode'], rel['id'],
-                               rel['properties'], type=rel['type'])
+                properties = copy.deepcopy(rel['properties'])
+                properties.update(
+                    id=rel['id'],
+                    type=rel['type']
+                )
+                graph.add_edge(rel['startNode'], rel['endNode'], properties)
         return graph
 
     def _get_graph(self):
